.if hlp
.HELPB FORMAT__OF__COMMANDS
.s
.else hlp
.CHAPTER RUNOFF COMMANDS 
.INDEX RUNOFF COMMANDS 
.INDEX COMMAND FORMAT 
.endif hlp
.ifnot small
This chapter contains a list of all RUNOFF commands. You may not
want to read all of this chapter, as it is intended to be a reference
manual.  If you have never used RUNOFF before, then you should
read the chapter "INTRODUCTION TO THE COMMANDS".
.endif small
.f.p
All commands begin with a period(.). 
.ifnot small
Any line in the source file beginning
with a period is assumed to contain one or more commands.  If the text after
the period is not recognized as a command, an error message is typed. 
.endif small
Most commands have arguments following them. An argument is a number or string
of text that controls how the command works. Multiple arguments can be
separated by spaces, tabs, or commas. If the arguments are separated by
commas, any number of tabs or spaces can appear before or after the comma.
Certain conventions are used to describe the arguments of a command.
If the argument is enclosed inside square brackets [], it can be omitted. 
.ifnot small
.if hlp
.if rsx .i5;FURTHER HELP: numbers literals multiple abbreviations
.endif rsx
.endif hlp
.HELPC NUMBERS
.p
.endif small
Most arguments are numbers.  If the number is
preceded by a minus sign (-), it will be entered as a negative value.  If
it is preceded by +-, it is a relative argument.  A relative argument
changes the old value by + or - the value specified. 
.ifnot small
Many arguments have limits.  For example, page numbers must be within the
range 1 to $NUMSIZ$.  Each command documents the limits on its arguments.
.p
For example, the command _.LEFT MARGIN 5, will set the left margin to
exactly 5, whereas the command _.LEFT MARGIN +5 will set the left margin
to its old value plus 5, and _.LEFT MARGIN -5 will set it to the old
value minus 5.
.HELPC LITERALS
.p
.endif small
Some commands have literal arguments.  A literal is a string of text
enclosed in either apostrophes (') or quotes (").
If quotes are used to delimit the string and you wish to use a quote inside
the string, you must use two quotes in a row.
.ifnot small
Similarly, if the text is enclosed in apostrophes, a double apostrophe
within the text will be interpreted as a single apostrophe.
For example legal literals are:
.i5;'"legal" literal'
.i5;"""legal"" literal"
.br;Either of these will appear as: "legal" literal
.br;The following are not legal literals:
.i5;'illegal literal"
.i5;'illegal' literal'
.i5;''illegal literal'
.br;Tabs enclosed inside a literal are treated as single spaces.
A literal is also terminated by the end of a line.  (This termination might
not be supported in future versions.)
.HELPC MULTIPLE
.p 
.endif small
More than one command can be entered on a single line.  The commands can be
optionally separated by a semicolon ";", spaces, or tabs. If a semicolon is
used as a separator, the next command must immediately follow with no
intervening spaces or tabs. A command that is followed by text must be the
last command on a line, and cannot have other commands after it on the same
line. 
.ifnot small
These include: 
.keep tabs
.ts +2,+17,+17,+17,+17,+17,+17 .nj.dhy
	_.APPENDIX	_.CHAPTER	_.FIRST#TITLE	_.HEADER#LEVEL
	_.INDEX	_.LIST#ELEMENT	_.REQUIRE	_.SEND
	_.SUBTITLE	_.TITLE
.j.ehy
For example, the following is a legal set of commands all on 1 line: 
.s.i5;_.TT 10 .Fill;.EH _.Title GONE WITH THE WIND 
.p; Commands can have text following them, provided the text is separated 
from the command by a semicolon (;).  For example, the following line will 
produce a centered title. 
.i5; _.C;THIS IS A TITLE 
.br; When the semicolon is used as a separator, it indicates that the rest 
of the line is to be treated just as if a new line had begun. 
.HELPC ABBREVIATIONS
.p
Many commands can be abbreviated. Standard abbreviations are given below each
command. Many other abbreviations will work, but only the standard ones are
guaranteed to work. Multi-word commands can appear without spaces. For
example, the following forms of the _.PAGE SIZE command are all legal: 
.text
.nf.lm+5
_.PAGE  SIZE 20,20, 4, 1, 1
_.PAGE SIZE 20 , 20
_.PAGESIZE 20 20
_.PS ,,1,2
_.ps , , 1 2
_.PAG SIZ 25
.lm.f
.end text
.p
Many commands have defaults.  In other words, if an argument is not
specified, a default value of the argument will be used.
.HELPC USER
.p
It is possible to define your own commands.  RUNOFF will search for 
either a standard command or a user defined command.  To specify
one or the other, preface a user command with an underscore "__" and
a standard command with a dollar sign "_$".  For example, you might have
a user command called FIGURE, but there is also a standard command of the
same name.  To use your command, type
.i5;_.__FIGURE
.br;and to use the standard command, type
.i5;_._$FIGURE
.endif small
